@@ -1,8 +1,5 @@
-.getPoolMean <- function(meth,unmeth)
+.getPoolMean <- function(meth,unmeth,s_t,s_c)
 {
-  s <- .sizeFactor2(cbind(meth,unmeth))
-  s_t <- s[1:length(meth[1,])]
-  s_c <- s[(length(meth[1,])+1):(length(cbind(meth,unmeth)[1,]))]
   # estimate probability of methylation under a condition
   p <- .estimateP(meth,unmeth, s_t,s_c)
   
@@ -12,6 +9,6 @@
   # estimate size e
   e <- .estimateE(meth,unmeth,s_t,s_c,q)
   
-  res <- list(s_t,s_c,p,q,e)
+  res <- list(p=p,q=q,e=e)
   return(res)
 }
\ No newline at end of file
